import { AutoDiscoverBase, IntegrationTestAutoDiscoverBase, IntegrationTestAutoDiscoverBaseOptions } from "../cdk";
import { Component } from "../component";
import { Project } from "../project";
import { AwsCdkDeps } from "./awscdk-deps";
import { LambdaFunctionCommonOptions } from "./lambda-function";
/**
 * (experimental) Common options for auto discovering project subcomponents.
 *
 * @experimental
 */
export interface AutoDiscoverCommonOptions {
    /**
     * (experimental) Path to the tsconfig file to use for integration tests.
     *
     * @experimental
     */
    readonly tsconfigPath: string;
    /**
     * (experimental) AWS CDK dependency manager.
     *
     * @experimental
     */
    readonly cdkDeps: AwsCdkDeps;
}
/**
 * (experimental) Options for `IntegrationTestAutoDiscover`.
 *
 * @experimental
 */
export interface IntegrationTestAutoDiscoverOptions extends AutoDiscoverCommonOptions, IntegrationTestAutoDiscoverBaseOptions {
}
/**
 * (experimental) Creates integration tests from entry points discovered in the test tree.
 *
 * @experimental
 */
export declare class IntegrationTestAutoDiscover extends IntegrationTestAutoDiscoverBase {
    /**
     * @experimental
     */
    constructor(project: Project, options: IntegrationTestAutoDiscoverOptions);
}
/**
 * (experimental) Options for `LambdaAutoDiscover`.
 *
 * @experimental
 */
export interface LambdaAutoDiscoverOptions extends AutoDiscoverCommonOptions {
    /**
     * (experimental) Project source tree (relative to project output directory).
     *
     * @experimental
     */
    readonly srcdir: string;
    /**
     * (experimental) Options for auto-discovery of AWS Lambda functions.
     *
     * @experimental
     */
    readonly lambdaOptions?: LambdaFunctionCommonOptions;
}
/**
 * (experimental) Creates lambdas from entry points discovered in the project's source tree.
 *
 * @experimental
 */
export declare class LambdaAutoDiscover extends AutoDiscoverBase {
    /**
     * @experimental
     */
    constructor(project: Project, options: LambdaAutoDiscoverOptions);
}
/**
 * (experimental) Options for `AutoDiscover`.
 *
 * @experimental
 */
export interface AutoDiscoverOptions extends LambdaAutoDiscoverOptions, IntegrationTestAutoDiscoverOptions {
    /**
     * (experimental) Auto-discover lambda functions.
     *
     * @default true
     * @experimental
     */
    readonly lambdaAutoDiscover?: boolean;
    /**
     * (experimental) Auto-discover integration tests.
     *
     * @default true
     * @experimental
     */
    readonly integrationTestAutoDiscover?: boolean;
}
/**
 * (experimental) Discovers and creates integration tests and lambdas from code in the project's source and test trees.
 *
 * @experimental
 */
export declare class AutoDiscover extends Component {
    /**
     * @experimental
     */
    constructor(project: Project, options: AutoDiscoverOptions);
}
