import { Component } from "../component";
import { Project } from "../project";
import { Task } from "../task";
/**
 * (experimental) Options for IntegrationTest.
 *
 * @experimental
 */
export interface IntegrationTestBaseOptions {
    /**
     * (experimental) Name of the integration test.
     *
     * @default - Derived from the entrypoint filename.
     * @experimental
     */
    readonly name?: string;
    /**
     * (experimental) A path from the project root directory to a TypeScript file which contains the integration test app.
     *
     * This is relative to the root directory of the project.
     *
     * @experimental
     * @example
     *
     * "test/subdir/foo.integ.ts"
     */
    readonly entrypoint: string;
    /**
     * (experimental) The path of the tsconfig.json file to use when running integration test cdk apps.
     *
     * @experimental
     */
    readonly tsconfigPath: string;
}
/**
 * @experimental
 */
export declare abstract class IntegrationTestBase extends Component {
    /**
     * (experimental) Deploy the integration test and update the snapshot upon success.
     *
     * @experimental
     */
    readonly deployTask: Task;
    /**
     * (experimental) Synthesizes the integration test and compares against a local copy (runs during build).
     *
     * @experimental
     */
    readonly assertTask: Task;
    /**
     * (experimental) Just update snapshot (without deployment).
     *
     * @experimental
     */
    readonly snapshotTask: Task;
    /**
     * (experimental) Temporary directory for each integration test.
     *
     * @experimental
     */
    protected readonly tmpDir: string;
    /**
     * (experimental) Snapshot output directory.
     *
     * @experimental
     */
    protected readonly snapshotDir: string;
    /**
     * (experimental) Integration test name.
     *
     * @experimental
     */
    protected readonly name: string;
    /**
     * @experimental
     */
    constructor(project: Project, options: IntegrationTestBaseOptions);
}
